<?php
/**
 * SocialLive functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package SocialLive
 */
if (!function_exists('sociallive_after_theme_support')) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function sociallive_after_theme_support()
    {
        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');
        // Custom background color.
        add_theme_support(
            'custom-background',
            array(
                'default-color' => 'ffffff',
            )
        );
        // This variable is intended to be overruled from themes.
        // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
        // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
        $GLOBALS['content_width'] = apply_filters('sociallive_content_width', 970);
        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');
        add_image_size('sociallive-featured-image', '960', '1280', true);
        add_theme_support(
            'custom-logo',
            array(
                'height' => 120,
                'width' => 90,
                'flex-height' => true,
                'flex-width' => true,
            )
        );
        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');
        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support(
            'html5',
            array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption',
                'script',
                'style',
            )
        );
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on SocialLive, use a find and replace
         * to change 'sociallive' to the name of your theme in all the template files.
         */
        load_theme_textdomain('sociallive', get_template_directory() . '/languages');
        // Add support for full and wide align images.
        add_theme_support('align-wide');
        add_theme_support('responsive-embeds');
        add_theme_support('wp-block-styles');
    }
endif;
add_action('after_setup_theme', 'sociallive_after_theme_support');
/**
 * Register and Enqueue Styles.
 */
function sociallive_register_styles()
{
    $sociallive_default = sociallive_get_default_theme_options();
    $theme_version = wp_get_theme()->get('Version');
    $fonts_url = sociallive_fonts_url();
    if ($fonts_url) {
        require_once get_theme_file_path('assets/lib/custom/css/wptt-webfont-loader.php');
        wp_enqueue_style(
            'sociallive-google-fonts',
            wptt_get_webfont_url($fonts_url),
            array(),
            $theme_version
        );
    }
    wp_enqueue_style('slick', get_template_directory_uri() . '/assets/lib/slick/slick.css');
    wp_enqueue_style('magnific-popup', get_template_directory_uri() . '/assets/lib/magnific-popup/magnific-popup.css');
    if (class_exists('WooCommerce')) {
        wp_enqueue_style('sociallive-woocommerce', get_template_directory_uri() . '/assets/lib/custom/css/woocommerce.css');
    }
    wp_enqueue_style('sociallive-style', get_stylesheet_uri(), array(), $theme_version);

    wp_style_add_data('sociallive-style', 'rtl', 'replace');

    wp_add_inline_style( 'sociallive-custom-style', sociallive_header_style() );

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
    wp_enqueue_script('imagesloaded');
    wp_enqueue_script('sociallive-pagination', get_template_directory_uri() . '/assets/lib/custom/js/pagination.js', array('jquery'), '', 1);
    wp_enqueue_script('slick', get_template_directory_uri() . '/assets/lib/slick/slick.min.js', array('jquery'), '', 1);
    wp_enqueue_script('jquery-magnific-popup', get_template_directory_uri() . '/assets/lib/magnific-popup/jquery.magnific-popup.min.js', array('jquery'), '', 1);
    wp_enqueue_script('sociallive-custom', get_template_directory_uri() . '/assets/lib/custom/js/custom.js', array('jquery'), '', 1);
    $ajax_nonce = wp_create_nonce('sociallive_ajax_nonce');
    // Global Query
    if (is_front_page()) {
        $posts_per_page = absint(get_option('posts_per_page'));
        $paged = (get_query_var('page')) ? absint(get_query_var('page')) : 1;
        $posts_args = array(
            'posts_per_page' => $posts_per_page,
            'paged' => $paged,
        );
        $posts_qry = new WP_Query($posts_args);
        $max = $posts_qry->max_num_pages;
    } else {
        global $wp_query;
        $max = $wp_query->max_num_pages;
        $paged = (get_query_var('paged') > 1) ? get_query_var('paged') : 1;
    }
    $sociallive_default = sociallive_get_default_theme_options();
    $sociallive_pagination_layout = get_theme_mod('sociallive_pagination_layout', $sociallive_default['sociallive_pagination_layout']);
    // Pagination Data
    wp_localize_script(
        'sociallive-pagination',
        'sociallive_pagination',
        array(
            'paged' => absint($paged),
            'maxpage' => absint($max),
            'nextLink' => next_posts($max, false),
            'ajax_url' => esc_url(admin_url('admin-ajax.php')),
            'loadmore' => esc_html__('Load More Posts', 'sociallive'),
            'nomore' => esc_html__('No More Posts', 'sociallive'),
            'loading' => esc_html__('Loading...', 'sociallive'),
            'pagination_layout' => esc_html($sociallive_pagination_layout),
            'ajax_nonce' => $ajax_nonce,
        )
    );
    global $post;
    $single_post = 0;
    wp_localize_script(
        'sociallive-custom',
        'sociallive_custom',
        array(
            'single_post' => absint($single_post),
            'next_svg' => sociallive_the_theme_svg('chevron-right', true),
            'prev_svg' => sociallive_the_theme_svg('chevron-left', true),
            'play' => sociallive_the_theme_svg('play', $return = true),
            'pause' => sociallive_the_theme_svg('pause', $return = true),
            'mute' => sociallive_the_theme_svg('mute', $return = true),
            'cross' => sociallive_the_theme_svg('cross', $return = true),
            'unmute' => sociallive_the_theme_svg('unmute', $return = true),
            'play_text' => esc_html__('Play', 'sociallive'),
            'pause_text' => esc_html__('Pause', 'sociallive'),
            'mute_text' => esc_html__('Mute', 'sociallive'),
            'unmute_text' => esc_html__('Unmute', 'sociallive'),
        )
    );
}
add_action('wp_enqueue_scripts', 'sociallive_register_styles');
/**
 * Admin enqueue script
 */
function sociallive_admin_scripts($hook)
{
    wp_enqueue_media();
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_style('sociallive-admin', get_template_directory_uri() . '/assets/lib/custom/css/admin.css');
    wp_enqueue_script('sociallive-admin', get_template_directory_uri() . '/assets/lib/custom/js/admin.js', array('jquery', 'wp-color-picker'), '', 1);
    $ajax_nonce = wp_create_nonce('sociallive_ajax_nonce');
    wp_localize_script(
        'sociallive-admin',
        'sociallive_admin',
        array(
            'ajax_url' => esc_url(admin_url('admin-ajax.php')),
            'ajax_nonce' => $ajax_nonce,
            'active' => esc_html__('Active', 'sociallive'),
            'deactivate' => esc_html__('Deactivate', 'sociallive'),
            'upload_image' => esc_html__('Choose Image', 'sociallive'),
            'use_image' => esc_html__('Select', 'sociallive'),
        )
    );
}
add_action('admin_enqueue_scripts', 'sociallive_admin_scripts');
function sociallive_customize_preview_js()
{
    wp_enqueue_script('sociallive-customizer-preview', get_template_directory_uri() . '/assets/lib/custom/js/customizer-preview.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'sociallive_customize_preview_js');
if (!function_exists('sociallive_js_no_js_class')) :
    // js no-js class toggle
    function sociallive_js_no_js_class()
    { ?>
        <script>document.documentElement.className = document.documentElement.className.replace('no-js', 'js');</script>
        <?php
    }
endif;
add_action('wp_head', 'sociallive_js_no_js_class');
/**
 * Register navigation menus uses wp_nav_menu in five places.
 */
function sociallive_menus()
{
    $locations = array(
        'sociallive-primary-menu' => esc_html__('Primary Menu', 'sociallive'),
        'sociallive-social-menu' => esc_html__('Social Menu', 'sociallive'),
    );
    register_nav_menus($locations);
}
add_action('init', 'sociallive_menus');
if (class_exists('Demo_Import_Kit_Class')):
    add_filter('themeinwp_enable_demo_import_compatiblity', 'sociallive_demo_import_filter_apply');
    if (!function_exists('sociallive_demo_import_filter_apply')):
        function sociallive_demo_import_filter_apply()
        {
            return true;
        }
    endif;
endif;
require get_template_directory() . '/assets/lib/tgmpa/recommended-plugins.php';
require get_template_directory() . '/classes/class-svg-icons.php';
require get_template_directory() . '/classes/class-walker-menu.php';
require get_template_directory() . '/classes/plugin-classes.php';
require get_template_directory() . '/classes/about.php';
require get_template_directory() . '/classes/admin-notice.php';
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/custom-functions.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/classes/body-classes.php';
require get_template_directory() . '/inc/term-meta.php';
require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/inc/pagination.php';
require get_template_directory() . '/inc/widgets/widgets.php';
require get_template_directory() . '/assets/lib/custom/css/style.php';
require get_template_directory() . '/woocommerce/woocommerce-functions.php';
require get_template_directory() . '/template-parts/banner-block.php';
require get_template_directory() . '/template-parts/single-related-post.php';

add_action('init', function () {
    $twp_sociallive_base_cat_url = basename($_SERVER['REQUEST_URI']);
    if ($twp_sociallive_base_cat_url == 'twp-video-browse-by-category') {
        // load the file if exists
        $load = locate_template('/template-parts/browse-by-cat.php', true);
        if ($load) {
            exit(); // just exit if template was found and loaded
        }
    }
});
remove_filter('the_excerpt', 'wpautop');
