<?php
/**
 * Header file for the SocialLive WordPress theme.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package SocialLive
 * @since 1.0.0
 */
?>
<!DOCTYPE html>
<html class="no-js" <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no"/>
    <link rel="profile" href="https://gmpg.org/xfn/11">
    <?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
<?php
if (function_exists('wp_body_open')) {
    wp_body_open();
} ?>
<div id="page" class="site theme-site">
    <a class="skip-link screen-reader-text" href="#content"><?php esc_html_e('Skip to the content', 'sociallive'); ?></a>
    <header id="site-header" class="theme-site-header" role="banner">
        <?php get_template_part('template-parts/header/header', 'content'); ?>
    </header>

    <div id="theme-content" class="theme-body-content">
        <?php 
        $sociallive_default = sociallive_get_default_theme_options();
        $enable_sidebar_filter = get_theme_mod( 'enable_sidebar_filter',$sociallive_default['enable_sidebar_filter'] );
        if($enable_sidebar_filter):
        ?>
            <aside class="theme-aside theme-aside-left">
                <a href="javascript:void(0)" class="theme-filter-toggle">
                    <span><?php echo esc_html__('Filter Contents', 'sociallive'); ?></span>
                    <span><?php sociallive_the_theme_svg('chevron-down'); ?></span>
                </a>
                <div id="theme-filter-content" class="theme-aside-content">
                    <div class="theme-filter theme-filter-category">
                        <h2 class="aside-filter-title">
                            <?php echo esc_html__('Filter By category', 'sociallive'); ?>
                        </h2>
                        <ul>
                            <?php
                            $args = array(
                                'orderby' => 'id',
                                'hide_empty' => 0,
                            );
                            $categories = get_categories($args);
                            foreach ($categories as $cats) { ?>
                                <li>
                                    <a href="<?php echo esc_url(get_category_link($cats->term_id)); ?>" class='filter-link'><?php echo esc_html($cats->name); ?></a>
                                </li>
                            <?php } ?>
                        </ul>

                        <div class="filter-toggle-button">
                            <a href=''> <?php echo esc_html__('Show More +','sociallive'); ?> </a>
                        </div>

                    </div>
                    <div class="theme-filter theme-filter-tag">
                        <h2 class="aside-filter-title">
                            <?php echo esc_html__('Filter By Tags', 'sociallive'); ?>
                        </h2>
                        <ul>
                            <?php
                            $tags = get_tags(array(
                                'hide_empty' => false
                            ));
                            foreach ($tags as $tagged) { ?>
                                <li>
                                    <a href="<?php echo esc_url(get_tag_link($tagged->term_id)); ?>"><?php echo esc_html($tagged->name); ?></a>
                                </li>
                            <?php } ?>
                        </ul>
                        <div class="filter-toggle-button">
                            <a href=''> <?php echo esc_html__('Show More +','sociallive'); ?> </a>
                        </div>

                    </div>
                    <div class="theme-filter them-filter-year">
                        <h2 class="aside-filter-title">
                            <?php echo esc_html__('Filter By Year', 'sociallive'); ?>
                        </h2>
                        <ul>
                            <?php
                            wp_get_archives(array('type' => 'yearly'));
                            ?>
                        </ul>
                    </div>
                    <div class="theme-filter theme-filter-author">
                        <h2 class="aside-filter-title">
                            <?php echo esc_html__('Filter By Author', 'sociallive'); ?>
                        </h2>
                        <?php
                        $users = get_users(array('fields' => array('display_name', 'id')));
                        // Array of stdClass objects.
                        foreach ($users as $user) { ?>
                            <ul>
                                <li>
                                    <a href="<?php echo esc_url(get_author_posts_url($user->id)); ?>"><?php echo esc_html($user->display_name); ?></a>
                                </li>
                            </ul>
                        <?php } ?>
                    </div>
                </div>
            </aside>
        <?php endif; ?>

        <div class="theme-panel theme-main-panel">
            <div id="content" class="site-content">
