<?php
/**
* Customizer Custom Classes.
*
* @package SocialLive
*/


/** Customizer Custom Control **/
if ( class_exists( 'WP_Customize_Control' ) ) {
    
    // Radio Image Custom Control Class.
    class SocialLive_Custom_Radio_Image_Control extends WP_Customize_Control {

        public $type = 'radio-image';
    
        public function render_content() {
           
            if ( empty( $this->choices ) ) {
                return;
            }           
            
            $name = '_customize-radio-' . $this->id; ?>
            
            <span class="customize-control-title">
                <?php echo esc_attr( $this->label ); ?>
                <?php if ( ! empty( $this->description ) ) : ?>
                    <span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
                <?php endif; ?>
            </span>
            
            <div id="input_<?php echo esc_attr($this->id); ?>" class="image radio-image-buttenset">
                <?php foreach ( $this->choices as $value => $label ) : ?>
                    <input class="image-select" type="radio" value="<?php echo esc_attr( $value ); ?>" id="<?php echo esc_attr($this->id) . esc_attr($value); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?>>
                        <label for="<?php echo esc_attr($this->id) . esc_attr($value); ?>">
                            <img src="<?php echo esc_html( $label ); ?>" alt="<?php echo esc_attr( $value ); ?>" title="<?php echo esc_attr( $value ); ?>">
                        </label>
                    </input>
                <?php endforeach; ?>
            </div>
            
        <?php }
    }

    /**
     * Customize Control for Taxonomy Select.
     *
     * @since 1.0.0
     *
     * @see WP_Customize_Control
     */
    class SocialLive_Dropdown_Taxonomies_Control extends WP_Customize_Control {

        /**
         * Control type.
         *
         * @access public
         * @var string
         */
        public $type = 'dropdown-taxonomies';

        /**
         * Taxonomy.
         *
         * @access public
         * @var string
         */
        public $taxonomy = '';

        /**
         * Constructor.
         *
         * @since 1.0.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      Control ID.
         * @param array                $args    Optional. Arguments to override class property defaults.
         */
        public function __construct( $manager, $id, $args = array() ) {

            $our_taxonomy = 'category';
            if ( isset( $args['taxonomy'] ) ) {
                $taxonomy_exist = taxonomy_exists( esc_attr( $args['taxonomy'] ) );
                if ( true === $taxonomy_exist ) {
                    $our_taxonomy = esc_attr( $args['taxonomy'] );
                }
            }
            $args['taxonomy'] = $our_taxonomy;
            $this->taxonomy = esc_attr( $our_taxonomy );

            parent::__construct( $manager, $id, $args );
        }

        /**
         * Render content.
         *
         * @since 1.0.0
         */
        public function render_content() {

            $tax_args = array(
                'hierarchical' => 0,
                'taxonomy'     => $this->taxonomy,
            );
            $all_taxonomies = get_categories( $tax_args );

            ?>
            <label>
                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                <select <?php $this->link(); ?>>
                    <?php
                    printf( '<option value="%s" %s>%s</option>', '', selected( $this->value(), '', false ), ' ' );
                    ?>
                    <?php if ( ! empty( $all_taxonomies ) ) :  ?>
                        <?php foreach ( $all_taxonomies as $key => $tax ) :  ?>
                            <?php
                            printf( '<option value="%s" %s>%s</option>', esc_attr( $tax->term_id ), selected( $this->value(), $tax->term_id, false ), esc_html( $tax->name ) );
                            ?>
                        <?php endforeach ?>
                    <?php endif ?>
                </select>
            </label>
            <?php
        }
    }
    
}

/**
 * Upsell customizer section.
 *
 * @since  1.0.0
 * @access public
 */
class SocialLive_Customize_Section_Upsell extends WP_Customize_Section {

    /**
     * The type of customize section being rendered.
     *
     * @since  1.0.0
     * @access public
     * @var    string
     */
    public $type = 'upsell';

    /**
     * Custom button text to output.
     *
     * @since  1.0.0
     * @access public
     * @var    string
     */
    public $pro_text = '';

    /**
     * Custom pro button URL.
     *
     * @since  1.0.0
     * @access public
     * @var    string
     */
    public $pro_url = '';

    public $notice = '';
    public $nonotice = '';

    /**
     * Add custom parameters to pass to the JS via JSON.
     *
     * @since  1.0.0
     * @access public
     * @return void
     */
    public function json() {
        $json = parent::json();

        $json['pro_text'] = $this->pro_text;
        $json['pro_url']  = esc_url( $this->pro_url );
        $json['notice']  = esc_attr( $this->notice );
        $json['nonotice']  = esc_attr( $this->nonotice );

        return $json;
    }

    /**
     * Outputs the Underscore.js template.
     *
     * @since  1.0.0
     * @access public
     * @return void
     */
    protected function render_template() { ?>

        <li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">

                <# if ( data.notice ) { #>
                    <h3 class="accordion-section-notice">
                        {{ data.title }}
                    </h3>
                <# } #>

                <# if ( !data.notice ) { #>
                    <h3 class="accordion-section-title">
                        {{ data.title }}

                        <# if ( data.pro_text && data.pro_url ) { #>
                            <a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
                        <# } #>
                    </h3>
                <# } #>
            
        </li>
    <?php }
}

if ( class_exists( 'WP_Customize_Control' ) ) {
    
    // Repeator Info
    class SocialLive_Premium_Notice_Control extends WP_Customize_Control {

        public $type = 'sociallive-premiuminfonotice';
    
        public function render_content() {
           
            $name = '_customize-notice-' . $this->id; ?>
            
            <span class="customize-control-title">
                <div class="theme-info-icon">
                    <div class="icon-notice-wrap">
                        <span class="dashicons dashicons-lightbulb twp-filter-icon"></span>
                        <span><?php echo esc_html__('More ','sociallive'). esc_html( $this->label ). esc_html__(' Available on Premium Version.', 'sociallive' ); ?></span>
                    </div>
                </div>
            </span>
            
        <?php }
    }
    
}

if ( ! function_exists( 'sociallive_is_select_latest_post' ) ) :

    /**
     * Check if slider section page/post is active.
     *
     * @since 1.0.0
     *
     * @param WP_Customize_Control $control WP_Customize_Control instance.
     *
     * @return bool Whether the control is active to the current preview.
     */
    function sociallive_is_select_latest_post( $control ) {

        if ( 'page' != $control->manager->get_setting( 'show_on_front' )->value() ) {
            return true;
        } else {
            return false;
        }

    }

endif;