<?php
/**
 * Carousel Post Widgets.
 *
 * @package SocialLive
 */
if (!function_exists('sociallive_carousel_post_widgets')) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function sociallive_carousel_post_widgets()
    {
        // Carousel Post widget.
        register_widget('SocialLive_Sidebar_Carousel_Posts_Widget');
    }
endif;
add_action('widgets_init', 'sociallive_carousel_post_widgets');
// Carousel Post widget
if (!class_exists('SocialLive_Sidebar_Carousel_Posts_Widget')) :
    /**
     * Carousel Post.
     *
     * @since 1.0.0
     */
    class SocialLive_Sidebar_Carousel_Posts_Widget extends SocialLive_Widget_Base
    {
        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'sociallive_carousel_post_widget',
                'description' => esc_html__('Displays post form selected category specific for popular post in sidebars.', 'sociallive'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Title:', 'sociallive'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'post_category' => array(
                    'label' => esc_html__('Select Category:', 'sociallive'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('All Categories', 'sociallive'),
                ),
                'enable_featured_image' => array(
                    'label' => esc_html__('Enable Featured Image:', 'sociallive'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'enable_author_image' => array(
                    'label' => esc_html__('Enable Author Image:', 'sociallive'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'slider_arrow' => array(
                    'label' => esc_html__('Slider Arrows:', 'sociallive'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'slider_dots' => array(
                    'label' => esc_html__('Slider Dots:', 'sociallive'),
                    'type' => 'checkbox',
                    'default' => false,
                ),
                'slider_autoplay' => array(
                    'label' => esc_html__('Slider Autoplay:', 'sociallive'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'post_number' => array(
                    'label' => esc_html__('Number of Posts:', 'sociallive'),
                    'type' => 'number',
                    'default' => 12,
                    'css' => 'max-width:60px;',
                    'min' => 1,
                    'max' => 12,
                ),
                'slide_to_show' => array(
                    'label' => esc_html__('Slide to Show', 'sociallive'),
                    'type' => 'number',
                    'default' => 4,
                    'css' => 'max-width:60px;',
                    'min' => 1,
                    'max' => 5,
                ),
            );
            parent::__construct('sociallive-carousel-posts', esc_html__('SocialLive: Carousel Widget', 'sociallive'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         * @since 1.0.0
         *
         */
        function widget($args, $instance)
        {
            $params = $this->get_params($instance);
            echo $args['before_widget'];

            $section_category = isset($params['post_category']) ? $params['post_category'] : '';
            $slider_arrows = isset($params['slider_arrow']) ? $params['slider_arrow'] : '';
            $slider_dots = isset($params['slider_dots']) ? $params['slider_dots'] : '';
            $slider_autoplay = isset($params['slider_autoplay']) ? $params['slider_autoplay'] : '';
            $slide_to_show = isset($params['slide_to_show']) ? $params['slide_to_show'] : '3';
            $post_number = isset($params['post_number']) ? $params['post_number'] : '';

            $home_section_title = esc_html($params['title']);

            $carousel_post_query = new WP_Query(array('post_type' => 'post', 'posts_per_page' => $post_number, 'post__not_in' => get_option("sticky_posts"), 'cat' => esc_html($section_category)));

            if ($slider_autoplay == 'yes') {
                $autoplay = 'true';
            } else {
                $autoplay = 'false';
            }
            if ($slider_dots == 'yes') {
                $dots = 'true';
            } else {
                $dots = 'false';
            }
            if (is_rtl()) {
                $rtl = 'true';
            } else {
                $rtl = 'false';
            }

            if ($carousel_post_query->have_posts()): ?>

                <div class="theme-custom-widget custom-widget-carousel">
                    <div class="wrapper">

                        <?php if (isset($params['title']) && $params['title']) { ?>

                            <div class="wrapper-inner">
                                <div class="column column-12">
                                    <header class="block-title-wrapper">
                                        <h3 class="theme-block-title theme-block-title-medium">
                                            <?php echo $home_section_title; ?>
                                        </h3>

                                        <?php if ($slider_arrows == 'true') { ?>
                                            <div class="theme-heading-controls">
                                                <button type="button" class="slide-btn slide-prev-carousel">
                                                    <?php sociallive_the_theme_svg('chevron-left'); ?>
                                                </button>
                                                <button type="button" class="slide-btn slide-next-carousel">
                                                    <?php sociallive_the_theme_svg('chevron-right'); ?>
                                                </button>
                                            </div>
                                        <?php } ?>

                                    </header>
                                </div>
                            </div>

                        <?php } ?>

                        <div class="theme-widget-carousel theme-slick-space" data-slick='{"slidesToShow": <?php echo $slide_to_show ?>, "slidesToScroll": <?php echo $slide_to_show ?>, "autoplay": <?php echo esc_attr($autoplay); ?>, "dots": <?php echo esc_attr($dots); ?>, "rtl": <?php echo esc_attr($rtl); ?>}'>
                            <?php while ($carousel_post_query->have_posts()) {
                                $carousel_post_query->the_post();
                                ?>
                                <div class="widget-carousel-item">
                                    <article id="theme-post-<?php the_ID(); ?>" <?php post_class('theme-post-article theme-post-carousel'); ?>>
                                        <?php
                                        $content = apply_filters('the_content', get_the_content());
                                        $video = false;
                                        $video_url = '';
                                        $video_url = sociallive_video_pop_up_url($content, $video, $video_url);

                                        $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                        $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
                                        $featured_image_full = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                                        $featured_image_full = isset($featured_image_full[0]) ? $featured_image_full[0] : '';

                                        if (has_post_thumbnail()) {
                                            if ($params['slide_to_show'] <= 3) {
                                                $twp_data_bg_size = 'data-bg-medium';
                                            } else {
                                                $twp_data_bg_size = 'data-bg-small';
                                            }
                                            if ($params['slide_to_show'] == 1) {
                                                $twp_data_bg_size = 'data-bg-big';
                                            }

                                            ?>
                                            <div class="theme-media-panel">
                                                <?php if (!empty($video_url)) { ?>
                                                    <a class="theme-media-link" href="<?php echo esc_url($video_url); ?>" data-title="<?php the_title_attribute(); ?>" data-caption="<?php the_excerpt(); ?>">
                                                        <span class="data-bg thumb-overlay img-hover-shine <?php echo $twp_data_bg_size; ?>" data-background="<?php echo esc_url($featured_image); ?>">
                                                            <span id="video-icon-holder">
                                                                <span id="media-video-icon"></span>
                                                            </span>
                                                        </span>
                                                    </a>
                                                <?php } else { ?>
                                                    <a class="popup-image-link" href="<?php echo esc_url($featured_image_full); ?>" data-title="<?php the_title_attribute(); ?>" data-caption="<?php the_excerpt(); ?>">
                                                        <span class="data-bg thumb-overlay img-hover-shine <?php echo $twp_data_bg_size; ?>" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                    </a>
                                                <?php } ?>
                                            </div>
                                        <?php } ?>


                                        <div class="article-content">
                                            <?php
                                            $enable_author_image = isset($params['enable_author_image']);
                                            if ($enable_author_image) { ?>
                                                <div class="article-content-left">
                                                    <?php $author_img = get_avatar(get_the_author_meta('ID'), 60, '', '', array('class' => 'avatar-img')); ?>
                                                    <div class="theme-author-image">
                                                        <?php echo wp_kses_post($author_img); ?>
                                                    </div>
                                                </div>
                                            <?php } ?>

                                            <div class="article-content-right">
                                                <header class="entry-header">
                                                    <h3 class="entry-title entry-title-small">
                                                        <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>">
                                                            <?php the_title(); ?>
                                                        </a>
                                                    </h3>
                                                </header>
                                                <div class="entry-meta">
                                                    <?php sociallive_posted_by(); ?>
                                                    <?php sociallive_posted_on(); ?>
                                                </div>
                                            </div>
                                        </div>
                                    </article>
                                </div>

                            <?php } ?>
                        </div>
                    </div>
                </div>

            <?php
            endif;

            wp_reset_postdata();

            echo $args['after_widget'];

        }
    }
endif;