<?php
/**
 * Category Widgets.
 *
 * @package SocialLive
 */
if (!function_exists('sociallive_category_widgets')) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function sociallive_category_widgets()
    {
        // Recent Post widget.
        register_widget('SocialLive_Sidebar_Category_Widget');
    }
endif;
add_action('widgets_init', 'sociallive_category_widgets');
// Recent Post widget
if (!class_exists('SocialLive_Sidebar_Category_Widget')) :
    /**
     * Recent Post.
     *
     * @since 1.0.0
     */
    class SocialLive_Sidebar_Category_Widget extends SocialLive_Widget_Base
    {
        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'sociallive_category_widget',
                'description' => esc_html__('Displays categories and posts.', 'sociallive'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Title:', 'sociallive'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'post_category_1' => array(
                    'label' => esc_html__('Select Category - 1:', 'sociallive'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('--- Select Categories ---', 'sociallive'),
                ),
                'post_category_2' => array(
                    'label' => esc_html__('Select Category - 2:', 'sociallive'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('--- Select Categories ---', 'sociallive'),
                ),
                'post_category_3' => array(
                    'label' => esc_html__('Select Category - 3:', 'sociallive'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('--- Select Categories ---', 'sociallive'),
                ),
                'post_category_4' => array(
                    'label' => esc_html__('Select Category - 4:', 'sociallive'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('--- Select Categories ---', 'sociallive'),
                ),
                'enable_cat_desc' => array(
                    'label' => esc_html__('Enable Category Description:', 'sociallive'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'latest_title' => array(
                    'label' => esc_html__('Latest Text Label:', 'sociallive'),
                    'type' => 'text',
                    'class' => 'widefat',
                    'default' => esc_html__('Latest', 'sociallive'),
                ),
            );
            parent::__construct('sociallive-category-layout', esc_html__('SocialLive: Category Widget', 'sociallive'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         * @since 1.0.0
         *
         */
        function widget($args, $instance)
        {
            $params = $this->get_params($instance);
            $latest_title = isset($params['latest_title']) ? $params['latest_title'] : '';
            echo $args['before_widget'];
            $home_section_title = esc_html($params['title']);
            $enable_cat_desc = $params['enable_cat_desc'];
            ?>
            <div class="theme-custom-widget custom-widget-category">
                <div class="wrapper">
                    <?php if (isset($params['title']) && $params['title']) { ?>
                        <div class="wrapper-inner">
                            <div class="column column-12">
                                <header class="block-title-wrapper">
                                    <h3 class="theme-block-title theme-block-title-medium">
                                        <?php echo $home_section_title; ?>
                                    </h3>
                                </header>
                            </div>
                        </div>
                    <?php } ?>
                    <div class="wrapper-inner">
                        <?php
                        $count = 0;
                        for ($i = 1; $i < 5; $i++) {
                            $post_category = $params['post_category_' . $i];
                            if (!empty($post_category)) {
                                $count++;
                            }
                        }
                        $number_oc_cat = $count;
                        switch ($number_oc_cat) {
                            case "1":
                                $twp_column_num = 'column-12';
                                break;
                            case "2":
                                $twp_column_num = 'column-6';
                                break;
                            case "3":
                                $twp_column_num = 'column-4';
                                break;
                            case "4":
                                $twp_column_num = 'column-3 column-sm-6 mb-sm-20';
                                break;
                            default:
                                $twp_column_num = 'column-4';
                        }
                        for ($i = 1; $i < 5; $i++) {
                            $post_category = $params['post_category_' . $i];
                            if (!empty($post_category)) {
                                $cat_link = get_category_link($post_category);
                                $cat_name = get_cat_name($post_category);
                                $cat_description = category_description($post_category);
                                $twp_term_image = get_term_meta($post_category, 'twp-term-featured-image', true);
                                ?>
                                <div class="column <?php echo $twp_column_num; ?> column-xs-12  mb-xs-20">
                                    <div class="theme-category-image">
                                        <a href="<?php echo esc_url($cat_link); ?>">
                                            <span class="data-bg data-bg-small" data-background="<?php echo esc_url($twp_term_image); ?>"></span>
                                        </a>
                                    </div>
                                    <div class="theme-category-content">
                                        <header class="category-widget-header">
                                            <h2 class="category-title">
                                                <a href="<?php echo esc_url($cat_link); ?>">
                                                   <?php echo esc_html($cat_name); ?>
                                                </a>
                                            </h2>
                                            <?php if ($enable_cat_desc && $cat_description) { ?>
                                                <div class="category-widget-description">
                                                    <?php echo wp_kses_post($cat_description); ?>
                                                </div>
                                            <?php } ?>
                                        </header>
                                        <div class="latest-category-post">
                                            <?php echo esc_html($latest_title); ?>
                                        </div>
                                    </div>
                                    <article
                                            id="theme-post-<?php the_ID(); ?>" <?php post_class('theme-post-article theme-post-category'); ?>>
                                        <?php
                                        $cat_posts = new WP_Query(array('post_type' => 'post', 'posts_per_page' => 1, 'category__in' => $post_category));
                                        while ($cat_posts->have_posts()) {
                                            $cat_posts->the_post();
                                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'thumbnail');
                                            $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';


                                            $featured_image_full = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                                            $featured_image_full = isset($featured_image_full[0]) ? $featured_image_full[0] : '';
                                            $content = apply_filters('the_content', get_the_content());
                                            $video = false;
                                            $video_url = '';
                                            $video_url = sociallive_video_pop_up_url($content, $video, $video_url);


                                            if (has_post_thumbnail()) {
                                                ?>
                                                <div class="theme-media-panel">
                                                    <?php if (!empty($video_url)) { ?>
                                                        <a class="theme-media-link" href="<?php echo esc_url($video_url); ?>" data-title="<?php the_title_attribute(); ?>" data-caption="<?php the_excerpt(); ?>">
                                                            <span class="data-bg data-bg-micro thumb-overlay img-hover-shine" data-background="<?php echo esc_url($featured_image); ?>">
                                                                <span id="video-icon-holder">
                                                                    <span id="media-video-icon"></span>
                                                                </span>
                                                            </span>
                                                        </a>
                                                    <?php } else { ?>
                                                        <a class="popup-image-link" href="<?php echo esc_url($featured_image_full); ?>" data-title="<?php the_title_attribute(); ?>" data-caption="<?php the_excerpt(); ?>">
                                                            <span class="data-bg data-bg-micro thumb-overlay img-hover-shine" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                        </a>
                                                    <?php } ?>
                                                </div>
                                            <?php } ?>

                                            <div class="article-content">
                                                <header class="entry-header">
                                                    <h3 class="entry-title entry-title-small">
                                                        <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>">
                                                            <?php the_title(); ?>
                                                        </a>
                                                    </h3>
                                                </header>
                                            </div>

                                        <?php }
                                        wp_reset_postdata(); ?>
                                    </article>
                                </div>
                            <?php }
                        }
                        ?>
                    </div>
                </div>
            </div>
            <?php
            echo $args['after_widget'];
        }
    }
endif;